==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/StringMatchFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface StringMatchFluent<A extends StringMatchFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildMatchType instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType getMatchType();
    public me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType buildMatchType();
    public A withMatchType(me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType matchType);
    public Boolean hasMatchType();
    public A withRegexMatchType(RegexMatchType regexMatchType);
    public StringMatchFluent.RegexMatchTypeNested<A> withNewRegexMatchType();
    public StringMatchFluent.RegexMatchTypeNested<A> withNewRegexMatchTypeLike(RegexMatchType item);
    public A withNewRegexMatchType(String regex);
    public A withPrefixMatchType(PrefixMatchType prefixMatchType);
    public StringMatchFluent.PrefixMatchTypeNested<A> withNewPrefixMatchType();
    public StringMatchFluent.PrefixMatchTypeNested<A> withNewPrefixMatchTypeLike(PrefixMatchType item);
    public A withNewPrefixMatchType(String prefix);
    public A withExactMatchType(ExactMatchType exactMatchType);
    public StringMatchFluent.ExactMatchTypeNested<A> withNewExactMatchType();
    public StringMatchFluent.ExactMatchTypeNested<A> withNewExactMatchTypeLike(ExactMatchType item);
    public A withNewExactMatchType(String exact);

    public interface RegexMatchTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RegexMatchTypeFluent<StringMatchFluent.RegexMatchTypeNested<N>>{

        
    public N and();    public N endRegexMatchType();
}
    public interface PrefixMatchTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PrefixMatchTypeFluent<StringMatchFluent.PrefixMatchTypeNested<N>>{

        
    public N and();    public N endPrefixMatchType();
}
    public interface ExactMatchTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExactMatchTypeFluent<StringMatchFluent.ExactMatchTypeNested<N>>{

        
    public N and();    public N endExactMatchType();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/StringMatchFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface StringMatchFluent<A extends me.snowdrop.istio.api.networking.v1alpha3.StringMatchFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildMatchType instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType getMatchType();
    public me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType buildMatchType();
    public A withMatchType(me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType matchType);
    public Boolean hasMatchType();
    public A withRegexMatchType(RegexMatchType regexMatchType);
    public StringMatchFluent.RegexMatchTypeNested<A> withNewRegexMatchType();
    public StringMatchFluent.RegexMatchTypeNested<A> withNewRegexMatchTypeLike(RegexMatchType item);
    public A withNewRegexMatchType(String regex);
    public A withPrefixMatchType(PrefixMatchType prefixMatchType);
    public StringMatchFluent.PrefixMatchTypeNested<A> withNewPrefixMatchType();
    public StringMatchFluent.PrefixMatchTypeNested<A> withNewPrefixMatchTypeLike(PrefixMatchType item);
    public A withNewPrefixMatchType(String prefix);
    public A withExactMatchType(ExactMatchType exactMatchType);
    public StringMatchFluent.ExactMatchTypeNested<A> withNewExactMatchType();
    public StringMatchFluent.ExactMatchTypeNested<A> withNewExactMatchTypeLike(ExactMatchType item);
    public A withNewExactMatchType(String exact);

    public interface RegexMatchTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RegexMatchTypeFluent<StringMatchFluent.RegexMatchTypeNested<N>>{

        
    public N and();    public N endRegexMatchType();
}
    public interface PrefixMatchTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PrefixMatchTypeFluent<StringMatchFluent.PrefixMatchTypeNested<N>>{

        
    public N and();    public N endPrefixMatchType();
}
    public interface ExactMatchTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExactMatchTypeFluent<StringMatchFluent.ExactMatchTypeNested<N>>{

        
    public N and();    public N endExactMatchType();
}


}
